@@ -1,13 +1,13 @@
 class Downloader(object):
     "Base downloader object"
-    def get(self, url):
+    def get(self, url, **kwargs):
         print("I'm a useless downloader :_")
 
 
 class DefaultDownloader(Downloader):
     "Downloader using urllib2"
 
-    def get(self, url):
+    def get(self, url, **kwargs):
         import urllib2
         try:
             req = urllib2.Request(url)
